@@ -4,19 +4,21 @@ from rate.readers.reader import Reader
 
 
 class JsonReader(Reader):
-    def __init__(self, file_name, columns_indexes: list):
-        super().__init__(file_name, columns_indexes)
+    def __init__(self, file_name):
+        super().__init__(file_name)
         data = json.load(self.file)
         self._keys = list(data[0].keys())
+        # init readonly keys to all keys
+        self.readonly_keys = self._keys
         self._reader = (i for i in data)
-        self.requested_columns = [self._keys[int(i)] for i in self.columns_indexes]
 
-    def next_record(self):
+    def next_record(self) -> dict:
         return next(self)
 
     def __next__(self):
         raw = next(self._reader)
-        return [raw[i] for i in self.requested_columns]
+        # return list of values for readonly keys from dict raw
+        return [raw[key] for key in self.readonly_keys]
 
     def __iter__(self):
         return self._reader
@@ -26,3 +28,8 @@ class JsonReader(Reader):
 
     def close(self):
         self.file.close()
+
+    def reset(self):
+        self.file.seek(0)
+        data = json.load(self.file)
+        self._reader = (i for i in data)
